==> _private_chat-0.0.20.tar.gz: lib/chat_detail/asset/bloc/chat_detail_asset_bloc.dart <==
import 'dart:async';

import 'package:_private_chat/chat_detail/message.dart';
import 'package:_private_core/constant.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../chat_detail_asset.dart';

part 'chat_detail_asset_event.dart';
part 'chat_detail_asset_state.dart';

class ChatDetailAssetBloc
    extends Bloc<ChatDetailAssetEvent, ChatDetailAssetState> {
  StreamSubscription? _subscription;

  DocumentReference<Map<String, dynamic>> get _docRef =>
      FirebaseFirestore.instance
          .collection(C_CONVERSATIONS)
          .doc(state.conversationData?[DB_KEY_CONVERSATION_ID]);

  CollectionReference<Map<String, dynamic>> get _colRef =>
      _docRef.collection(C_MESSAGES);

  ChatDetailAssetBloc() : super(ChatDetailAssetState(images: [])) {
    on<InitChatDetailAssetEvent>(_init);
    on<UpdateChatDetailAssetEvent>(_update);
    on<DisposeChatDetailAssetEvent>(_dispose);
  }

  _init(event, emit) async {
    state.conversationData = event.conversationData;

    QuerySnapshot query = await _colRef
        .orderBy(DB_KEY_TIMESTAMP)
        .where(DB_KEY_MESSAGE_TYPE, isEqualTo: MessageType.image.index)
        .get();

    add(UpdateChatDetailAssetEvent(query.docs.map((e) {
      return ChatDetailAsset(
          data: e.data() as Map,
          timestamp: (e.data() as Map)[DB_KEY_TIMESTAMP]);
    }).toList()));

    _subscription = _colRef
        .orderBy(DB_KEY_TIMESTAMP)
        .where(DB_KEY_MESSAGE_TYPE, isEqualTo: MessageType.image.index)
        .snapshots()
        .listen((query) {
      add(UpdateChatDetailAssetEvent(query.docs.map((e) {
        return ChatDetailAsset(
            data: e.data(), timestamp: (e.data())[DB_KEY_TIMESTAMP]);
      }).toList()));
    });
  }

  _update(event, emit) {
    emit(state.update(images: event.images));
  }

  _dispose(event, emit) {
    _subscription?.cancel();
  }
}

==> _private_chat-1.0.16.tar.gz: lib/chat_detail/asset/bloc/chat_detail_asset_bloc.dart <==
import 'dart:async';

import 'package:_private_chat/chat_detail/message.dart';
import 'package:_private_chat/constant.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../chat_detail_asset.dart';

part 'chat_detail_asset_event.dart';
part 'chat_detail_asset_state.dart';

class ChatDetailAssetBloc
    extends Bloc<ChatDetailAssetEvent, ChatDetailAssetState> {
  StreamSubscription? _subscription;

  DocumentReference<Map<String, dynamic>> get _docRef =>
      FirebaseFirestore.instance
          .collection(kCollectionCONVERSATIONS)
          .doc(state.conversationData?[kDbCONVERSATIONID]);

  CollectionReference<Map<String, dynamic>> get _colRef =>
      _docRef.collection(kCollectionMESSAGES);

  ChatDetailAssetBloc() : super(ChatDetailAssetState(images: [])) {
    on<InitChatDetailAssetEvent>(_init);
    on<UpdateChatDetailAssetEvent>(_update);
    on<DisposeChatDetailAssetEvent>(_dispose);
  }

  _init(event, emit) async {
    state.conversationData = event.conversationData;

    QuerySnapshot query = await _colRef
        .orderBy(kDbTIMESTAMP)
        .where(kDbMESSAGETYPE, isEqualTo: MessageType.image.index)
        .get();

    add(UpdateChatDetailAssetEvent(query.docs.map((e) {
      return ChatDetailAsset(
          data: e.data() as Map, timestamp: (e.data() as Map)[kDbTIMESTAMP]);
    }).toList()));

    _subscription = _colRef
        .orderBy(kDbTIMESTAMP)
        .where(kDbMESSAGETYPE, isEqualTo: MessageType.image.index)
        .snapshots()
        .listen((query) {
      add(UpdateChatDetailAssetEvent(query.docs.map((e) {
        return ChatDetailAsset(
            data: e.data(), timestamp: (e.data())[kDbTIMESTAMP]);
      }).toList()));
    });
  }

  _update(event, emit) {
    emit(state.update(images: event.images));
  }

  _dispose(event, emit) {
    _subscription?.cancel();
  }
}
